changeset 110353:5f841657c901

* lisp/calendar/appt.el (appt-check): Doc fix.
author Glenn Morris <rgm@gnu.org>
date Tue, 14 Sep 2010 00:21:03 -0700
parents 7c4d14415111
children c9ceab6b914b
files lisp/ChangeLog lisp/calendar/appt.el
diffstat 2 files changed, 5 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Tue Sep 14 00:15:06 2010 -0700
+++ b/lisp/ChangeLog	Tue Sep 14 00:21:03 2010 -0700
@@ -5,6 +5,7 @@
 	(diary-include-other-diary-files): Append to diary-included-files.
 	* calendar/appt.el (appt-update-list): Also check the members of
 	diary-included-files.  (Bug#6999)
+	(appt-check): Doc fix.
 
 2010-09-12  David Reitter  <david.reitter@gmail.com>
 
--- a/lisp/calendar/appt.el	Tue Sep 14 00:15:06 2010 -0700
+++ b/lisp/calendar/appt.el	Tue Sep 14 00:21:03 2010 -0700
@@ -47,8 +47,9 @@
 ;; package is activated.  Additionally, the appointments list is
 ;; recreated automatically at 12:01am for those who do not logout
 ;; every day or are programming late.  It is also updated when the
 ;; `diary-file' is saved.  Calling `appt-check' with an argument (or
 ;; re-enabling the package) forces a re-initialization at any time.
 ;;
 ;; In order to add or delete items from today's list, without
 ;; changing the diary file, use `appt-add' and `appt-delete'.
@@ -261,7 +262,7 @@
   "Check for an appointment and update any reminder display.
 If optional argument FORCE is non-nil, reparse the diary file for
 appointments.  Otherwise the diary file is only parsed once per day,
-and when saved.
+or when it (or a file it includes) is saved.
 
 Note: the time must be the first thing in the line in the diary
 for a warning to be issued.  The format of the time can be either
@@ -47,8 +47,9 @@
 ;; recreated automatically at 12:01am for those who do not logout
 ;; every day or are programming late.  It is also updated when the
-;; `diary-file' is saved.  Calling `appt-check' with an argument (or
-;; re-enabling the package) forces a re-initialization at any time.
+;; `diary-file' (or a file it includes) is saved.  Calling
+;; `appt-check' with an argument (or re-enabling the package) forces a
+;; re-initialization at any time.
 ;;
 ;; In order to add or delete items from today's list, without